# nylira-maze

A JavaScript library for generating maze data.

    _________________________________________________________________________________
    |    ________ | |█|   |█|   |   |   |█|█|  __   |  ________ |█|  ______ |█|█|█| |
    |_| |  ____ | | |█| | |█| |___| | |_______|█| |___|    __ |  ___|  __ |________ |
    |█| |__ |█| |___|█| | |█|____ | |______ |  ___|█|  _| |█| | |  ___|█|__ |█|█|█| |
    |█| |  _|█|______ | |_________| |█|   | |__ |█|█| |█| |█|_| | |█|█|   |____ |___|
    |█| | |█|__ |█|█|____________ |_____|___|  _| |█|__ | |█|█| |  _|█| |____ | |   |
    |  _| |█|█| |   |█|   |█|   |________ |█| |  _|   | |_______| |  ___|__ | |___| |
    |__ | |  ___| | |█| | |█| |____ |█|█| |█| |  ___| | |█|█|█|█| | |█|█|█| | |  __ |
    |█| | | |  ___|_____| |█| |█|█|_______|█| |___|█| |__ | |   | |______ |  _| |█| |
    |  _| | | |█|█|  _____| | |█|   |____  _|__ |█|█|_______| | | |  __ | |__ | |  _|
    | |█| | | | |█|__ |█|█|_______| |█|█| |█|█|_______________|_____|█|_| |█|___|___|
    |__ | | | |__ |█| |  ______ |█|__ |█| |  ______  __ |█|█|  ____ |█|█|____ |█|█|█|
    |█| | | |____ |█| | |  __ |__ |█| |  _| |  __ |__ | |█|  _|█|█|________ |  __ |█|
    |  _|____ |█| |█|_____|█|_|█|__ | |_____| |  _|  _|  _|__ |  ______ |█| | |█|__ |
    | |  _____|█| |█|______ |█|█|  _| |   |█| |_____|█| |  ___| |  ____ |█| | |█|█| |
    | |________ |__ |█|█|█|__ |█| |█|__ |_____|█|█|█|___| |█|█| | |   |_|  _|____ | |
    |    ___|█|__ | |__ |   |_____|█|  _|  ____ |█|  __ | |  ___| | | |█|__ |█|___| |
    | |__ |█|█|  _| |█|___|____   |  _|█| |█|█|_____|█| | | |█|  _| | |█|█| |█|█|  _|
    | |█| |█|  _|  _|  _________| |_|█|█| | |█|  __  _|___| |█|_____|____ |____ |__ |
    |_|█| |  _|  _|  _|█| |█|█|█| |  _____|  ___|  _|█|█|█| |   |  _|█|  _|█|█| |█| |
    |█|█|___|█|_____|█|█|___________|█|█|█|_|█|█|_____________|___|█|█|_____________|

## Installation

    npm i nylira-maze --save

## Usage

Basic usage:

    var maze = require('nylira-maze')

    // returns a 2d array of values for a 10x10 maze
    maze()

    // returns a 2d array of values for a 20x20 maze
    maze(20)

    // returns a 2d array of values for a 15x23 maze
    maze(15, 23)

## Parameters

    maze(31, 23, 'growing-tree:newest', 0.47, undefined, true)

* **Parameter 1:** Width.
* **Parameter 2:** Height.
* **Parameter 3:** The maze generation algorithm. Options:
  * `"growing-tree"`: The Growing Tree algorithm. Defaults to `random`.
  * `"growing-tree:random"`: Lots of dead ends, similar to Prim's Algorithm
  * `"growing-tree:newest"`: Long windy passages, similar to `"backtracker"`
  * `"growing-tree:middle"`: Lots of long straight passages.
  * `"growing-tree:oldest"`: Only long straight passages.
  * `"backtracker"`: The Recursive Backtracker algorithm. Tends towards long and twisted passages.
* **Parameter 4:** Sparseness. A sparse maze will have some of its nodes removed. If you type in a value less than 1, e.g. 0.25, the maze will be 25% sparse. If you enter an integer value more than 1, e.g. 5, the maze will remove 5 nodes from each of its dead ends.
* **Parameter 5:** The integer seed for the maze. Putting a value here will guaranteee you can recreate the maze over and over again.
* **Parameter 6:** You can preview the grid by passing in `true` as the fifth parameter.

That function call above will generate the following:

    _______________________________________________________________
    |█|█|█|█|█|█|█|█|█|█|█|█|  ______ |█|█|█|█|   |█|█|█|█|█|█|█|█|
    |█|█|█|█|█|█|█|█|  _______|█|█|█| |█|█|█|█| |__ |█|█|█|█|█|█|█|
    |█|█|█|   |█|█|█| |█|█|█|█|█|█|█| |█|█|█|█|__ | |█|█|█|█|█|█|█|
    |█|█|  _|_________|█|█|█|  __ |  _|█|█|  _____| |█|█|█|  ____ |
    |█|█| |   |  _____________|█| | |█|█|█| |█|█|█| |█|█|█| |█|█| |
    |█|█| | |___|█|█|█|█|  _______|__ |█|█| |█|█|█| |   |█| |█|█| |
    |█|█| | |  _|█|█|█|█|__ |█|█|█|█|__ |  _|█|█|█|___| |█|____ | |
    |█|█|_____|█|█|█|█|█|  _|█|█|   |█| | |█|█|█|█|█|█| |█|█|___| |
    |█|█|█|█|█|█|█|█|█|█|______ | | |█| |____ |█|█|█|  _|█|█|█|   |
    |█|█|█|█|█|█|█|█|█|█|█|█|█|___|__ | |   | |█|█|█|________ | | |
    |█|█|█|█|   |█|█|█|█|█|█|█|  _____| | |___|█|█|█|█|█|█|█|___| |
    |█|█|█|█| | |█|█|█|█|█|█|█| |  ___|___|█|█|█|█|█|█|█|█|█|  ___|
    |█|█|█|█| |____ |  _________|__ |█|█|█|█|█|█|█|   |█|█|█|____ |
    |█|█|█|█|____ | |__ |█|  _______|█|█|█|█|█|   | | |█|█|█|  ___|
    |█|█|█|█|█|  _|_____|█| |  ____ |█|█|█|█|█| | | |_________|█|█|
    |█|█|█|█|█| |█|█|  _____| |█|█| |█|█|█|█|█| |___|█|█|█|█|█|█|█|
    |█|█|█|█|█| |█|█| |█|   | |█|█|______ |█|█| |█|█|█|█|█|█|█|█|█|
    |█|█|█| |█|___|█| |  _| |__________ | |█|█| |█|█|█|█|█|█|█|█|█|
    |█|█|█| |█|█|█|█| | |█| |█|█|█|  ___| |█|█| |█|█|█|█|█|█|█|█|█|
    |█|█|  _|█|  _______|█| |█|█|█| |█|█| |█|█|____ |█|█|█|█|█|█|█|
    |█|█| |  ___|█|█|█|█|█| |█|█|█| |█|█| |█|█|█|█| |█|█|█|█| |█|█|
    |█|█|___|█|█|█|█|█|█|█|__ |█|█| |█|█|______ |█| |  _______|█|█|
    |█|█|█|█|█|█|█|█|█|█|█|█|_______|█|█|█|█|█|_______|█|█|█|█|█|█|

## Test

See if it works.

    npm test

## License

MIT
